from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File

Fold_V0_1_0 = CommandToolBuilder(tool="Fold", base_command=["Fold"], inputs=[ToolInput(tag="in_dna", input_type=Boolean(optional=True), prefix="--DNA", doc=InputDocumentation(doc="Specify that the sequence is DNA, and DNA parameters are to be used.\nDefault is to use RNA parameters.")), ToolInput(tag="in_disable_coax", input_type=Boolean(optional=True), prefix="--disablecoax", doc=InputDocumentation(doc="Specify that coaxial stacking recusions should not be used. This option\nuses a less realistic energy function in exchange for a faster\ncalculation.")), ToolInput(tag="in_bracket", input_type=Boolean(optional=True), prefix="--bracket", doc=InputDocumentation(doc="Write the predicted structure in dot-bracket notation (DBN) instead of CT\nformat.")), ToolInput(tag="in_mfe", input_type=Boolean(optional=True), prefix="--MFE", doc=InputDocumentation(doc="Specify that only the minimum free energy structure is needed.\nNo savefiles can be generated.\nThis saves nearly half the calculation time, but provides less\ninformation.")), ToolInput(tag="in_quiet", input_type=File(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Suppress unnecessary output. This option is implied when the output file is\n'-' (STDOUT).")), ToolInput(tag="in_simple_i_loops", input_type=Boolean(optional=True), prefix="--simple_iloops", doc=InputDocumentation(doc="Specify that the O(N^3) internal loop search should be used. This speeds up\nthe calculation if large internal loops are allowed using the -l option.")), ToolInput(tag="in_alphabet", input_type=Boolean(optional=True), prefix="--alphabet", doc=InputDocumentation(doc="Specify the name of a folding alphabet and associated nearest neighbor\nparameters. The alphabet is the prefix for the thermodynamic parameter\nfiles, e.g. 'rna' for RNA parameters or 'dna' for DNA parameters or a\ncustom extended/modified alphabet. The thermodynamic parameters need to\nreside in the at the location indicated by environment variable DATAPATH.\nThe default is 'rna' (i.e. use RNA parameters). This option overrides the\n--DNA flag.")), ToolInput(tag="in_bootstrap", input_type=Boolean(optional=True), prefix="--bootstrap", doc=InputDocumentation(doc="Specify the number of bootstrap iterations to be done to retrieve base pair\nconfidence.\nDefaults to no bootstrapping.")), ToolInput(tag="in_constraint", input_type=Boolean(optional=True), prefix="--constraint", doc=InputDocumentation(doc="Specify a constraints file to be applied.\nDefault is to have no constraints applied.")), ToolInput(tag="in_cm_ct", input_type=Boolean(optional=True), prefix="--CMCT", doc=InputDocumentation(doc="Specify a CMCT constraints file to be applied. These constraints are\npseudoenergy constraints.\nDefault is to have no constraints applied.")), ToolInput(tag="in_dms", input_type=Boolean(optional=True), prefix="--DMS", doc=InputDocumentation(doc="Specify a DMS restraints file to be applied. These restraints are\npseudoenergy constraints.\nDefault is to have no restraints applied.")), ToolInput(tag="in_d_shape", input_type=Boolean(optional=True), prefix="--DSHAPE", doc=InputDocumentation(doc="Specify a differential SHAPE restraints file to be applied. These\nconstraints are pseudoenergy restraints.\nDefault is to have no restraints applied.")), ToolInput(tag="in_d_shape_slope", input_type=Boolean(optional=True), prefix="--DSHAPEslope", doc=InputDocumentation(doc="Specify a slope used with differential SHAPE restraints.\nDefault is 2.11 kcal/mol.")), ToolInput(tag="in_double_offset", input_type=Boolean(optional=True), prefix="--doubleOffset", doc=InputDocumentation(doc="Specify a double-stranded offset file, which adds energy bonuses to\nparticular double-stranded nucleotides.\nDefault is to have no double-stranded offset specified.")), ToolInput(tag="in_loop", input_type=Boolean(optional=True), prefix="--loop", doc=InputDocumentation(doc="Specify a maximum internal/bulge loop size.\nDefault is 30 unpaired numcleotides.")), ToolInput(tag="in_maximum", input_type=Boolean(optional=True), prefix="--maximum", doc=InputDocumentation(doc="Specify a maximum number of structures.\nDefault is 20 structures.")), ToolInput(tag="in_max_distance", input_type=Boolean(optional=True), prefix="--maxdistance", doc=InputDocumentation(doc="Specify a maximum pairing distance between nucleotides.\nDefault is no restriction on distance between pairs.")), ToolInput(tag="in_name", input_type=Boolean(optional=True), prefix="--name", doc=InputDocumentation(doc="Specify a name for the sequence. This will override the name in the\nsequence file.")), ToolInput(tag="in_percent", input_type=Boolean(optional=True), prefix="--percent", doc=InputDocumentation(doc="Specify a maximum percent energy difference.\nDefault is 10 percent (specified as 10, not 0.1).")), ToolInput(tag="in_save", input_type=Boolean(optional=True), prefix="--save", doc=InputDocumentation(doc="Specify the name of a save file, needed for dotplots and refolding.\nDefault is not to generate a save file.")), ToolInput(tag="in_shape", input_type=Boolean(optional=True), prefix="--SHAPE", doc=InputDocumentation(doc="Specify a SHAPE restraints file to be applied. These constraints are\npseudoenergy restraints.\nDefault is to have no restraints applied.")), ToolInput(tag="in_shape_intercept", input_type=Boolean(optional=True), prefix="--SHAPEintercept", doc=InputDocumentation(doc="Specify an intercept used with SHAPE restraints.\nDefault is -0.6 kcal/mol.")), ToolInput(tag="in_shape_slope", input_type=Boolean(optional=True), prefix="--SHAPEslope", doc=InputDocumentation(doc="Specify a slope used with SHAPE renstraints.\nDefault is 1.8 kcal/mol.")), ToolInput(tag="in_single_offset", input_type=Boolean(optional=True), prefix="--singleOffset", doc=InputDocumentation(doc="Specify a single-stranded offset file, which adds energy bonuses to\nparticular single-stranded nucleotides.\nDefault is to have no single-stranded offset specified.")), ToolInput(tag="in_temperature", input_type=Boolean(optional=True), prefix="--temperature", doc=InputDocumentation(doc="Specify the temperature at which calculation takes place in Kelvin.\nDefault is 310.15 K, which is 37 degrees C.")), ToolInput(tag="in_unpaired_shape_intercept", input_type=Boolean(optional=True), prefix="--unpairedSHAPEintercept", doc=InputDocumentation(doc="Specify an intercept used with unpaired SHAPE constraints.\nDefault is 0 kcal/mol.")), ToolInput(tag="in_unpaired_shape_slope", input_type=Boolean(optional=True), prefix="--unpairedSHAPEslope", doc=InputDocumentation(doc="Specify a slope used with unpaired SHAPE constraints.\nDefault is 0 kcal/mol.")), ToolInput(tag="in_window", input_type=Boolean(optional=True), prefix="--window", doc=InputDocumentation(doc="Specify a window size.\nDefault is determined by the length of the sequence.")), ToolInput(tag="in_warnings", input_type=Boolean(optional=True), prefix="--warnings", doc=InputDocumentation(doc="Set the behavior for non-critical warnings (e.g. related to invalid\nnucleotide positions or duplicate data points in SHAPE data). Valid values\nare:\n* on  -- Warnings are written to standard output. (default)\n* err -- Warnings are sent to STDERR. This can be used in automated scripts\netc to detect problems.\n* off -- Do not display warnings at all (not recommended).")), ToolInput(tag="in_experimental_pair_bonus", input_type=Boolean(optional=True), prefix="--experimentalPairBonus", doc=InputDocumentation(doc="Input text file with bonuses (in kcal) as a matrix. As with SHAPE, bonuses\nwill be applied twice to internal base pairs, once to edge base pairs, and\nnot at all to single stranded regions.\nDefault is no experimental pair bonus file specified.")), ToolInput(tag="in_xo", input_type=Boolean(optional=True), prefix="-xo", doc=InputDocumentation(doc="Specify an intercept (overall offset) to use with the 2D experimental pair\nbonus file.\nDefault is 0.0 (no change to input bonuses).")), ToolInput(tag="in_xs", input_type=Boolean(optional=True), prefix="-xs", doc=InputDocumentation(doc="Specify a number to multiply the experimental pair bonus matrix by.\nDefault is 1.0 (no change to input bonuses).\n")), ToolInput(tag="in_sequence_file", input_type=File(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_ct_file", input_type=File(), position=1, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_quiet", output_type=File(optional=True), selector=InputSelector(input_to_select="in_quiet", type_hint=File()), doc=OutputDocumentation(doc="Suppress unnecessary output. This option is implied when the output file is\n'-' (STDOUT)."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Fold_V0_1_0().translate("wdl", allow_empty_container=True)

